@@ -5,12 +5,11 @@ We can then use a standard template and inject details from the
 specific transformation as we know the methods and properties available.
 """
 from abc import ABC, abstractmethod, abstractproperty
+import os
 from typing import Optional
 
 from igi_file_transformation_contract.result import TransformationResult
 
-UNASSIGNED_OUT_PATH = "<AutoAssign>"
-
 
 class IFileTransformer(ABC):
     """
@@ -21,18 +20,6 @@ class IFileTransformer(ABC):
     are not required to implement this interface.
     """
 
-    @abstractmethod
-    def try_transform_file(
-        self, in_path: str, out_path: str = UNASSIGNED_OUT_PATH, **kwargs
-    ) -> TransformationResult:
-        pass
-
-    @abstractmethod
-    def transform_file(
-        self, in_path: str, out_path: str = UNASSIGNED_OUT_PATH, **kwargs
-    ) -> str:
-        pass
-
     @abstractproperty
     def title(self) -> str:
         pass
@@ -40,21 +27,32 @@ class IFileTransformer(ABC):
     @abstractproperty
     def user_description(self) -> str:
         """
-        A user friendly description of the transformation that can be displayed on the
-        webpage.
+        A user friendly description of the task that can be displayed on the webpage.
         """
         pass
 
+    @abstractmethod
+    def try_transform_file(self, in_path: str, out_path: str, **kwargs) -> TransformationResult:
+        pass
+
+    @abstractmethod
+    def transform_file(self, in_path: str, out_path: str, **kwargs) -> str:
+        pass
+
     @abstractproperty
     def result_disclaimer(self) -> str:
         """
-        E.g. We have tried to map the headers to the IGI property model correctly, but
-        cannot anticipate all possible inputs, so please check the indication, uom etc
-        assigned in the headers to ensure that you are happy with the mapping.
-        Please send any corrections to ...
+        Advice on what to check in output etc.
         """
         pass
 
+    @property
+    def target_file_ext(self) -> str:
+        """
+        Extention for target output file - any overrides should include the . prefix
+        """
+        return '.xlsx'
+
     @property
     def user_description_image_uri(self) -> Optional[str]:
         """
@@ -74,3 +72,14 @@ class IFileTransformer(ABC):
 
     def has_result_disclaimer_image_uri(self) -> bool:
         return bool(self.result_disclaimer_image_uri)
+
+    def get_default_output_path(self, in_path) -> str:
+        directory, filename = os.path.split(in_path)
+        output_filename = self.get_default_output_filename(input_filename=filename)
+        return os.path.join(directory, output_filename)
+
+    def get_default_output_filename(self, input_filename: str) -> str:
+        base_name, _ = os.path.split(input_filename)
+        output_filename = f"{base_name}_transformed{self.target_file_ext}"
+        return output_filename
+
